@@ -9,7 +9,7 @@ Requires Python 2.6 or later
 __author__       = 'Mike Taylor (bear@code-bear.com)'
 __copyright__    = 'Copyright (c) 2004 Mike Taylor'
 __license__      = 'Apache v2.0'
-__version__      = '1.1.1'
+__version__      = '1.1.2'
 __contributors__ = [ 'Darshana Chhajed',
                      'Michael Lim (lim.ck.michael@gmail.com)',
                      'Bernd Zeimetz (bzed@debian.org)',
@@ -206,7 +206,7 @@ class Calendar:
         Default constructor for the L{Calendar} class.
 
         @type  constants: object
-        @param constants: Instance of the class L{parsedatetime_consts.Constants}
+        @param constants: Instance of the class L{Constants}
 
         @rtype:  object
         @return: L{Calendar} instance
